proc MomentCurvature2D { secTag axialLoad maxK {numIncr 100} dj} {
	##################################################
	# A procedure for performing section analysis (only does
	# moment-curvature, but can be easily modified to do any mode
	# of section reponse.)
	#
	# MHS
	# October 2000
	# modified to 2D and to improve convergence by Silvia Mazzoni, 2006
	#
	# Arguments
	#	secTag -- tag identifying section to be analyzed
	#	axialLoad -- axial load applied to section (negative is compression)
	#	maxK -- maximum curvature reached during analysis
	#	numIncr -- number of increments used to reach maxK (default 100)
	#
	# Sets up a recorder which writes moment-curvature results to file
	# section$secTag.out ... the moment is in column 1, and curvature in column 2

	# Define two nodes at (0,0)
	node 1001 0.0 0.0
	node 1002 0.0 0.0

	# Fix all degrees of freedom except axial and bending
	fix 1001 1 1 1
	fix 1002 0 1 0

	# Define element
	#                          tag     ndI    ndJ  secTag
	element zeroLengthSection  1       1001   1002  $secTag


	# output moment (col 1) & curvature (col 2)
	recorder Node -file Mfi_$secTag.out -time -node 1002 -dof 3 disp
	
	# Define constant axial load
	pattern Plain 3001 "Constant" {
		load 1002 $axialLoad 0.0 0.0
	}

	# Define analysis parameters
	integrator LoadControl 0 1 0 0
	system SparseGeneral -piv;	# Overkill, but may need the pivoting!
	test EnergyIncr  1.0e-9 10
	numberer Plain
	constraints Plain
	algorithm Newton
	analysis Static

	# Do one analysis for constant axial load
	analyze 1
	
	loadConst -time 0.0

	# Create recorder
	recorder Node -file dataMphi.out -time -node 1002 -dof 3 disp	
	recorder Element -file Element1.out -time -ele 1 section fiber 10.5 0.0 deformation
	recorder Element -file Concrete1.out -time -ele 1 section fiber [expr -$dj/2] 0 1 stressStrain
	recorder Element -file Concrete2.out -time -ele 1 section fiber [expr -3*$dj/8] 0 1 stressStrain
	recorder Element -file Concrete3.out -time -ele 1 section fiber [expr -$dj/4] 0 1 stressStrain
	recorder Element -file Concrete4.out -time -ele 1 section fiber [expr -$dj/8] 0 1 stressStrain
	recorder Element -file Concrete5.out -time -ele 1 section fiber 0 0 1 stressStrain
	recorder Element -file Concrete6.out -time -ele 1 section fiber [expr $dj/8] 0 1 stressStrain
	recorder Element -file Concrete7.out -time -ele 1 section fiber [expr $dj/4] 0 1 stressStrain
	recorder Element -file Concrete8.out -time -ele 1 section fiber [expr 3*$dj/8] 0 1 stressStrain
	recorder Element -file Concrete9.out -time -ele 1 section fiber [expr $dj/2] 0 1 stressStrain
	recorder Element -file Steel.out -time -ele 1 section fiber [expr -$dj/2] 0 3 stressStrain
	recorder Element -file Steel2.out -time -ele 1 section fiber [expr $dj/2] 0 3 stressStrain
	recorder Element -file ConcreteC.out -time -ele 1 section fiber [expr 1.3*$dj/2] 0 2 stressStrain
	
	
	# Define reference moment
	pattern Plain 3002 "Linear" {
		load 1002 0.0 0.0 1.0
	}

	# Compute curvature increment
	#set dK [expr $maxK/$numIncr]
	set dK 0.00002
	set currentDisp 0.0;
	set ok 0

	# Use displacement control at node 1002 for section analysis, dof 3
	integrator DisplacementControl 1002 3 $dK 1 $dK $dK

	while {$ok == 0 && $currentDisp < $maxK} {

		set ok [analyze 1]

		# if the analysis fails try initial tangent iteration
		if {$ok != 0} {
			puts "regular newton failed .. lets try an initail stiffness for this step"
			test NormDispIncr 1.0e-12  1000 
			algorithm ModifiedNewton -initial
			set ok [analyze 1]
		if {$ok == 0} {puts "that worked .. back to regular newton"}
			test NormDispIncr 1.0e-12  10 
			algorithm Newton
		}

		set currentDisp [nodeDisp 1002 3]
	}

	

}



## BASIC

# Create ModelBuilder (with two-dimensions and 3 DOF/node)
model BasicBuilder -ndm 2 -ndf 3

source parameters.tcl

##--------------------------------------------------------------------------

## DEFINE MATERIALS FOR NONLINEAR COLUMNS

# CONCRETE
# Core concrete (confined)
#uniaxialMaterial Concrete04 $matTag $fc $ec $ecu $Ec <$fct $et> <$beta>
uniaxialMaterial Concrete04 1  $fc $ec $ecu $Ec
# Cover concrete (unconfined)
#uniaxialMaterial Concrete04 2  $fc $ec $ecu $Ec
#uniaxialMaterial Concrete01 $matTag $fpc $epsc0 $fpcu $epsU
uniaxialMaterial Concrete01  2      $fpc $epsc0 $fpcu $epsU
# Steel reinforcement
#uniaxialMaterial ReinforcingSteel $matTag $fy $fu $Es $Esh $esh $eult < -GABuck $lsr $beta $r $gama > < -DMBuck $lsr < $alpha >> < -CMFatigue $Cf $alpha $Cd > < -IsoHard <$a1 <$limit> > >
uniaxialMaterial ReinforcingSteel 4 $fy $fu $Es $Esh $esh $eult -DMBuck $lsr
uniaxialMaterial MinMax 3 4 -min -0.5 -max 0.5

##--------------------------------------------------------------------------

## DEFINE CROSS-SECTION FOR NONLINEAR COLUMNS

source prerez.tcl

##--------------------------------------------------------------------------  

## ESTIMATE YIELD CURVATURE

######################################
# As proposed in examples
# (Assuming no axial load and only top and bottom steel)
#set epsy [expr $fy/$Es]	;# steel yield strain
#set Ky [expr $epsy/(0.7*$d)]
######################################

#As proposed by Fardis 2003
#set epsy 0.0023
#set Ky [expr 2.1*$epsy/($d)*(1+$P/($d*$d*$fc)*30)]
#set Ky 0.0052
##	KY IZBEREMO NA PODLAGI IZMERJENIH VREDNOSTI

# Print estimate to standard output
puts "Estimated yield curvature: $Ky"

##-------------------------------------------------------------------------- 

## ANALYSIS

set mu 1.7;		# Target ductility for analysis
set numIncr 100;	# Number of analysis increments

# Call the section analysis procedure [expr $mu*$Ky]
MomentCurvature2D 1 $P [expr $mu*$Ky] 1000 $dj