#units in cm kN

source parameters.tcl
source pomiki.tcl


model basic -ndm 2 -ndf 3
##--------------------------------------------------------------------------

# OVERALL MODEL GEOMETRY

## 1.) COLUMN REPRESENTED WITH A SINGLE ELEMENT
# Create nodes
#    tag        X       Y 
node  1       0.0     0.0 
node  2       0.0	   $h
	
# Fix supports at base of columns
#    tag   DX   DY   RZ
fix   1     1    1    1
##--------------------------------------------------------------------------

# DEFINE MATERIALS FOR NONLINEAR COLUMNS

# 1.) COVER - Concrete01 / CORE - Concrete04 / STEEL - ReinforcingSteel

# CONCRETE

# Core concrete (confined)

#uniaxialMaterial Concrete07 $matTag $fc $ec $Ec $ft $et     $xp  $xn  $r
uniaxialMaterial Concrete07  1		 $fc $ec $Ec 0.2 0.00004 2.0  20   1.6

# Cover concrete (unconfined)
#uniaxialMaterial Concrete01 $matTag $fpc $epsc0 $fpcu $epsU
uniaxialMaterial Concrete01  2       $fpc $epsc0 $fpcu $epsU

# STELLL REINFORCEMENT

uniaxialMaterial ReinforcingSteel 4 $fy $fu $Es $Esh $esh $eult;# -DMBuck $lsr
uniaxialMaterial MinMax 3 4 -min -0.2 -max 0.2

##--------------------------------------------------------------------------

# DEFINE CROSS-SECTION FOR NONLINEAR COLUMNS

source prerez.tcl

##--------------------------------------------------------------------------

# DEFINE COLUMN ELEMENTS

# Geometry of column elements
#                tag 
geomTransf PDelta 1

# Number of integration points along length of element
set np 7

# Create the coulumns using Beam-column elements
set eleType forceBeamColumn

#element beamWithHinges $eleTag $iNode $jNode $secTagI $Lpi $secTagJ $Lpj $E  $A $Iz	$transfTag 
element beamWithHinges 1		1	   2	  1		   $Lpl 1		 $Lpl $Ec $A $Ieff	1 


##--------------------------------------------------------------------------

# DEFINE GRAVITY LOAD

# node that is a point of action
set nd 2

# Create a Plain load pattern with a Linear TimeSeries
pattern Plain 1 "Linear" {

        # Create nodal loads at node 2
	#    nd    FX          FY  MZ 
	load  $nd   0.0   [expr $P]  0.0

}
##--------------------------------------------------------------------------

# DEFINE BASIC ANALYSIS

# Create the system of equation, a sparse solver with partial pivoting
system BandGeneral

# Create the constraint handler, the transformation method
constraints Transformation

# Create the DOF numberer, the reverse Cuthill-McKee algorithm
numberer RCM

# Create the convergence test, the norm of the residual with a tolerance of 
# 1e-12 and a max number of iterations of 10
test NormDispIncr 1.0e-12  10 3

# Create the solution algorithm, a Newton-Raphson algorithm
algorithm Newton

# Create the integration scheme, the LoadControl scheme using steps of 0.1 
integrator LoadControl 0.1

# Create the analysis object
analysis Static
##--------------------------------------------------------------------------

#DO ANALYSIS

# perform the gravity load analysis, requires 5 steps to reach the load level
analyze 5

# Print out the state of node 2
print node $nd

puts "Gravity Analysis Completed"

# Resets the time in analysis
loadConst -time 0.0
##--------------------------------------------------------------------------

# DEFINE CYCLIC LOAD

set H 1.0;		# Reference lateral load

pattern Plain 2 "Linear" {

     # Create nodal loads at node 2
     #    nd    FX  FY  MZ 
     load $nd     $H 0.0 0.0  
}
##--------------------------------------------------------------------------

# DEFINE RECORDERS

recorder Node -file drift.out -time -node $nd -dof 1 2 3 disp
recorder Element -file Element1.out -time -ele 1 section fiber 10.5 0.0 deformation
recorder Element -file Concrete1.out -time -ele 1 section fiber [expr -$dj/2] 0 1 stressStrain
recorder Element -file Concrete2.out -time -ele 1 section fiber [expr -3*$dj/8] 0 1 stressStrain
recorder Element -file Concrete3.out -time -ele 1 section fiber [expr -$dj/4] 0 1 stressStrain
recorder Element -file Concrete4.out -time -ele 1 section fiber [expr -$dj/8] 0 1 stressStrain
recorder Element -file Concrete5.out -time -ele 1 section fiber 0 0 1 stressStrain
recorder Element -file Concrete6.out -time -ele 1 section fiber [expr $dj/8] 0 1 stressStrain
recorder Element -file Concrete7.out -time -ele 1 section fiber [expr $dj/4] 0 1 stressStrain
recorder Element -file Concrete8.out -time -ele 1 section fiber [expr 3*$dj/8] 0 1 stressStrain
recorder Element -file Concrete9.out -time -ele 1 section fiber [expr $dj/2] 0 1 stressStrain
recorder Element -file Steel.out -time -ele 1 section fiber [expr -$dj/2] 0 3 stressStrain
recorder Element -file Steel2.out -time -ele 1 section fiber [expr $dj/2] 0 3 stressStrain
recorder Element -file ConcreteC.out -time -ele 1 section fiber [expr 1.3*$dj/2] 0 2 stressStrain


##--------------------------------------------------------------------------

# PROCEDURE FOR CYCLIC LOADING

proc DispCyclicLoad {DispInc DispAmpl direction nd} {
	set dU $DispInc;	        # Displacement increment
	set maxU $DispAmpl;	        # Max displacement
	set currentDisp 0.0;
	set ok 0
	
	set criterion 1.0e-3
	set NumIter 1000
	
	# Code is diferent when the displacementi is positive and when is negative
	if {$direction>0} {
		# Change the integration scheme to be displacement control
		#                             node dof init Jd min max
		integrator DisplacementControl  $nd   1   $dU  1 $dU $dU
		#Calculates force(time) needed to make displacement step until sum of displacement is less than maxU
		while {$ok == 0 && $currentDisp < $maxU} {
			#Newton-Raphson method that was set in section analisis
			set ok [analyze 1]
	
			# if the analysis fails try initial tangent iteration
			if {$ok != 0} {
				puts "regular newton failed .. lets try an initail stiffness for this step"
				test NormDispIncr $criterion  $NumIter 
				algorithm ModifiedNewton -initial
				set ok [analyze 1]
			if {$ok == 0} {puts "that worked .. back to regular newton"}
				test NormDispIncr $criterion  $NumIter 
				algorithm Newton
			}
	
			set currentDisp [nodeDisp $nd 1]
		}
	} else {
		integrator DisplacementControl  $nd   1   [expr -$dU]  1 [expr -$dU] [expr -$dU]
		while {$ok == 0 && $currentDisp > $maxU} {
	
			set ok [analyze 1]
	
			# if the analysis fails try initial tangent iteration
			if {$ok != 0} {
				puts "regular newton failed .. lets try an initail stiffness for this step"
				test NormDispIncr $criterion  $NumIter 
				algorithm ModifiedNewton -initial
				set ok [analyze 1]
			if {$ok == 0} {puts "that worked .. back to regular newton"}
				test NormDispIncr $criterion  $NumIter 
				algorithm Newton
			}
	
			set currentDisp [nodeDisp $nd 1]
		}
	}

	if {$ok == 0} {
	puts "Cyclic analysis completed SUCCESSFULLY";
	} else {
	puts "Cyclic analysis FAILED";    
	}
};

##--------------------------------------------------------------------------

# DEFINE AND DO CYCLIC ANALYSIS

set velikost [array size pomiki]

puts $velikost

# run procedure for cyclic analysis

set SizeStep $StepSize

set i 1
while {$i<=[expr $velikost-1]} {
set j [expr $i-1]
set direction [expr $pomiki($i)-$pomiki($j)]
DispCyclicLoad 0.01 $pomiki($i) $direction $nd
puts $i
set i [expr $i+1]
}

##--------------------------------------------------------------------------
